@@ -765,11 +765,20 @@ _g_vfs_daemon_call_sync (DBusMessage *message,
 	  if (poll_ret == -1)
 	    {
 	      dbus_pending_call_unref (pending);
+	      g_cancellable_release_fd (cancellable);
 	      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
 			   "Error while getting peer-to-peer dbus connection: %s",
 			   "poll error");
 	      goto out;
 	    }
+
+	  if (poll_fds[0].revents & (G_IO_NVAL |  G_IO_ERR | G_IO_HUP))
+	    {
+	      dbus_pending_call_unref (pending);
+	      g_cancellable_release_fd (cancellable);
+	      invalidate_local_connection (dbus_id, error);
+	      goto out;
+	    }
 	  
 	  if (!sent_cancel && g_cancellable_is_cancelled (cancellable))
 	    {
@@ -926,8 +935,8 @@ _g_dbus_connection_get_sync (const char *dbus_id,
 	    return local->session_bus;
 
 	  /* Session bus was disconnected, re-connect */
-	  local->session_bus = NULL;
 	  dbus_connection_unref (local->session_bus);
+	  local->session_bus = NULL;
 	}
     }
   else
