@@ -68,6 +68,12 @@ daemon_init (void)
 
   g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG, log_debug, NULL);
 
+#ifdef SIGPIPE
+  /* Ignore SIGPIPE to avoid killing daemons on cancelled transfer *
+   * See https://bugzilla.gnome.org/show_bug.cgi?id=649041         *
+   */
+  signal (SIGPIPE, SIG_IGN);
+#endif
   
   dbus_error_init (&derror);
   connection = dbus_bus_get (DBUS_BUS_SESSION, &derror);
@@ -87,7 +93,7 @@ daemon_setup (void)
 
   up = g_ascii_strup (G_STRINGIFY (DEFAULT_BACKEND_TYPE), -1);
   /* translators: This is the default daemon's application name, 
-   * the %s is the type of the backend, like "ftp" */
+   * the %s is the type of the backend, like "FTP" */
   name = g_strdup_printf (_("%s Filesystem Service"), up);
   g_set_application_name (name);
   g_free (name);
