@@ -138,81 +138,64 @@ g_vfs_backend_http_init (GVfsBackendHttp *backend)
 /* public utility functions */
 
 SoupURI *
-http_backend_uri_for_filename (GVfsBackend *backend,
-                               const char  *filename,
-                               gboolean     is_dir)
+http_backend_get_mount_base (GVfsBackend *backend)
 {
-  GVfsBackendHttp *op_backend;
-  SoupURI         *uri;
-  char            *path;
+  return  G_VFS_BACKEND_HTTP (backend)->mount_base;
+}
 
-  op_backend = G_VFS_BACKEND_HTTP (backend);
-  uri = soup_uri_copy (op_backend->mount_base);
+char *
+http_path_get_basename (const char *path)
+{
+  const char *parent;
+  char       *basename;
+  size_t      len;
 
-  /* "/" means "whatever mount_base is" */
-  if (!strcmp (filename, "/"))
-    return uri;
+  if (path == NULL || *path == '\0')
+    return NULL;
 
-  /* Otherwise, we append filename to mount_base (which is assumed to
-   * be a directory in this case).
-   *
-   * Add a "/" in cases where it is likely that the url is going
-   * to be a directory to avoid redirections
-   */
-  if (is_dir == FALSE || g_str_has_suffix (filename, "/"))
-    path = g_build_path ("/", uri->path, filename, NULL);
+  /* remove any leading slashes */
+  while (*path != '\0' && (*path == '/' || *path == ' '))
+    path++;
+
+  len = strlen (path);
+  if (len == 0)
+    return g_strdup ("/");
+
+  /* remove any trailing slashes */
+  while (len)
+    {
+      char c = path[len - 1];
+      if (!g_ascii_isspace (c) && c != '/')
+	break;
+
+      len--;
+    }
+
+  parent = g_strrstr_len (path, len, "/");
+
+  if (parent)
+    {
+      parent++; /* skip the found / char */
+      basename = g_strndup (parent, (len - (parent - path)));
+    }
   else
-    path = g_build_path ("/", uri->path, filename, "/", NULL);
+    basename = g_strndup (path, len);
 
-  g_free (uri->path);
-  uri->path = g_uri_escape_string (path, G_URI_RESERVED_CHARS_ALLOWED_IN_PATH,
-                                   FALSE);
-  g_free (path);
-
-  return uri;
+  return basename;
 }
 
 char *
 http_uri_get_basename (const char *uri_str)
 {
-    const char *parent;
-    const char *path;
-    char       *to_free;
-    char       *basename;
-    size_t      len;
+  char *decoded;
+  char *basename;
 
-    if (uri_str == NULL || *uri_str == '\0')
-      return NULL;
+  basename = http_path_get_basename (uri_str);
 
-    path =  uri_str;
+  decoded = soup_uri_decode (basename);
+  g_free (basename);
 
-    /* remove any leading slashes */
-    while (*path == '/' || *path == ' ')
-        path++;
-
-    len = strlen (path);
-
-    if (len == 0)
-      return g_strdup ("/");
-
-    /* remove any trailing slashes */
-    while (path[len - 1] == '/' || path[len - 1] == ' ')
-        len--;
-
-    parent = g_strrstr_len (path, len, "/");
-
-    if (parent)
-      {
-        parent++; /* skip the found / char */
-        to_free = g_strndup (parent, (len - (parent - path)));
-      }
-    else
-      to_free = g_strndup (path, len);
-
-    basename = soup_uri_decode (to_free);
-    g_free (to_free);
-
-    return basename;
+  return decoded;
 }
 
 guint
@@ -384,10 +367,8 @@ try_open_for_read (GVfsBackend        *backend,
 {
   SoupURI *uri;
 
-  uri = http_backend_uri_for_filename (backend, filename, FALSE);
-
+  uri = http_backend_get_mount_base (backend);
   http_backend_open_for_read (backend, G_VFS_JOB (job), uri);
-  soup_uri_free (uri);
 
   return TRUE;
 }
@@ -685,9 +666,8 @@ try_query_info (GVfsBackend           *backend,
   SoupMessage *msg;
   SoupURI     *uri;
 
-  uri = http_backend_uri_for_filename (backend, filename, FALSE);
+  uri = http_backend_get_mount_base (backend);
   msg = soup_message_new_from_uri (SOUP_METHOD_HEAD, uri);
-  soup_uri_free (uri);
 
   http_backend_queue_message (backend, msg, query_info_ready, job);
 
