@@ -50,8 +50,6 @@
 #include "metabuilder.h"
 #include <glib.h>
 #include <glib/gstdio.h>
-#include <errno.h>
-#include <poll.h>
 #include "crc32.h"
 
 #ifdef HAVE_LIBUDEV
@@ -593,9 +591,7 @@ meta_tree_lookup_by_name (const char *name,
 MetaTree *
 meta_tree_ref (MetaTree *tree)
 {
-  gint old_val;
-
-  old_val = g_atomic_int_exchange_and_add ((int *)&tree->ref_count, 1);
+  g_atomic_int_exchange_and_add ((int *)&tree->ref_count, 1);
   return tree;
 }
 
@@ -1445,7 +1441,7 @@ meta_journal_reverse_map_path_and_key (MetaJournal *journal,
 				       guint64 *mtime,
 				       gpointer *value)
 {
-  PathKeyData data = {0};
+  PathKeyData data = {NULL};
   char *res_path;
 
   data.key = key;
@@ -1700,7 +1696,7 @@ get_child_info (EnumDirData *data,
   char *name;
 
   slash = strchr (remainder, '/');
-  if (slash != 0)
+  if (slash != NULL)
     name = g_strndup (remainder, slash - remainder);
   else
     name = g_strdup (remainder);
@@ -2763,7 +2759,7 @@ struct _MetaLookupCache {
 
 #ifdef HAVE_LIBUDEV
 
-struct udev *udev;
+static struct udev *udev;
 G_LOCK_DEFINE_STATIC (udev);
 
 static char *
@@ -2958,7 +2954,8 @@ parse_mountinfo (const char *contents)
 	  g_array_append_val (a, new_entry);
 	}
 
-      line = strchr (line, '\n');
+      if (line)
+	line = strchr (line, '\n');
       if (line)
 	line++;
     }
@@ -2989,7 +2986,7 @@ update_mountinfo (void)
   char *contents;
   int res;
   gboolean first;
-  struct pollfd pfd;
+  GPollFD pfd;
 
   first = FALSE;
   if (!mountinfo_initialized)
@@ -3005,9 +3002,9 @@ update_mountinfo (void)
   if (!first)
     {
       pfd.fd = mountinfo_fd;
-      pfd.events = POLLIN | POLLOUT | POLLPRI;
+      pfd.events = G_IO_IN | G_IO_OUT | G_IO_PRI;
       pfd.revents = 0;
-      res = poll (&pfd, 1, 0);
+      res = g_poll (&pfd, 1, 0);
       if (res == 0)
 	return;
     }
@@ -3085,7 +3082,7 @@ find_mountpoint_for (MetaLookupCache *cache,
 {
   char *first_dir, *dir, *last;
   const char *prefix;
-  dev_t dir_dev;
+  dev_t dir_dev = 0;
 
   first_dir = get_dirname (file);
   if (first_dir == NULL)
@@ -3106,8 +3103,7 @@ find_mountpoint_for (MetaLookupCache *cache,
     {
       if (dir)
 	dir_dev = get_devnum (dir);
-      if (dir == NULL ||
-	  dev != dir_dev)
+      if (dir == NULL || dev != dir_dev)
 	{
 	  g_free (dir);
 	  cache->last_parent_mountpoint = last;
